.. _spkg_sagemath_database_kohel:

==================================================================================
sagemath_database_kohel: Database of modular and Hilbert polynomials
==================================================================================


This pip-installable distribution ``passagemath-database-kohel`` is a
distribution of a database of modular and Hilbert polynomials.


What is included
----------------

- Wheels on PyPI include the database_kohel files


Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_database_kohel`
- :ref:`spkg_sage_conf`
- :ref:`spkg_sage_setup`
- :ref:`spkg_sagemath_environment`
- :ref:`spkg_setuptools`

Version Information
-------------------

package-version.txt::

    10.6.13

version_requirements.txt::

    passagemath-database-kohel ~= 10.6.13.0

Equivalent System Packages
--------------------------

(none known)
